%% new_RCell
%   creates a new Cell in the current RGrid
% inputs:
%   object:RGrid - current RGrid object
%   cell1:Cell - reference to condition cell in top grid
%   cell2:Cell - reference to condition cell in left grid
% outputs;
%   none
% Author: Colin Eles elesc@mcmaster.ca
% Organization: McMaster Centre for Software Certification
function [] = new_RCell(object,cell1,cell2)
cell = RCell;
cell.Cell1 = cell1;
cell.Cell2 = cell2;
object.Cells = [object.Cells cell];
end

